package cz.moneta.test.dsl.mwf;

import cz.moneta.test.harness.support.mwf.ApiVersion;
import cz.moneta.test.harness.support.mwf.MwfRequest;
import cz.moneta.test.harness.support.mwf.Parameter;

public interface MWF111 extends MwfRequest<MWF111, MWF111Response> {

    @Parameter(name = "Adresat")
    MWF111 adresat(String adresat);
    @Parameter(name = "CO")
    MWF111 co(String co);
    @Parameter(name = "CP")
    MWF111 cp(String cp);
    @Parameter(name = "CisloPasu")
    MWF111 cisloPasu(String cisloPasu);
    @Parameter(name = "Ctvrt")
    MWF111 ctvrt(String ctvrt);
    @Parameter(name = "DIC")
    MWF111 dic(String dic);
    @Parameter(name = "DatumExpiraceKontaktnichUdaju")
    MWF111 datumExpiraceKontaktnichUdaju(java.util.Date datumExpiraceKontaktnichUdaju);
    @Parameter(name = "DatumPlatnostiOP")
    MWF111 datumPlatnostiOP(java.util.Date datumPlatnostiOP);
    @Parameter(name = "DatumPodnikaniDo")
    MWF111 datumPodnikaniDo(java.util.Date datumPodnikaniDo);
    @Parameter(name = "DatumPodnikaniOd")
    MWF111 datumPodnikaniOd(java.util.Date datumPodnikaniOd);
    @Parameter(name = "DatumZalozeniCIFu")
    MWF111 datumZalozeniCIFu(java.util.Date datumZalozeniCIFu);
    @Parameter(name = "DruheJmeno")
    MWF111 druheJmeno(String druheJmeno);
    @Parameter(name = "EMail")
    MWF111 eMail(String eMail);
    @Parameter(name = "EkonomickySektor")
    MWF111 ekonomickySektor(String ekonomickySektor);
    @Parameter(name = "Funkce")
    MWF111 funkce(String funkce);
    @Parameter(name = "ICO")
    MWF111 ico(String ico);
    @Parameter(name = "ICOHlavnihoSpolku")
    MWF111 iCOHlavnihoSpolku(String iCOHlavnihoSpolku);
    @Parameter(name = "InsolvencniSpravce")
    MWF111 insolvencniSpravce(String insolvencniSpravce);
    @Parameter(name = "JinyOsobniDoklad2Cislo")
    MWF111 jinyOsobniDoklad2Cislo(String jinyOsobniDoklad2Cislo);
    @Parameter(name = "JinyOsobniDoklad2Platnost")
    MWF111 jinyOsobniDoklad2Platnost(java.util.Date jinyOsobniDoklad2Platnost);
    @Parameter(name = "JinyOsobniDoklad2Typ")
    MWF111 jinyOsobniDoklad2Typ(String jinyOsobniDoklad2Typ);
    @Parameter(name = "Jmeno")
    MWF111 jmeno(String jmeno);
    @Parameter(name = "KodObchodnihoMista")
    MWF111 kodObchodnihoMista(String kodObchodnihoMista);
    @Parameter(name = "OKEC")
    MWF111 okec(String okec);
    @Parameter(name = "OROddil")
    MWF111 oROddil(String oROddil);
    @Parameter(name = "ORSoud")
    MWF111 oRSoud(String oRSoud);
    @Parameter(name = "ORVlozka")
    MWF111 oRVlozka(String oRVlozka);
    @Parameter(name = "ObchodniJmeno")
    MWF111 obchodniJmeno(String obchodniJmeno);
    @Parameter(name = "Obec")
    MWF111 obec(String obec);
    @Parameter(name = "Osloveni")
    MWF111 osloveni(String osloveni);
    @Parameter(name = "OsobniBanker")
    MWF111 osobniBanker(String osobniBanker);
    @Parameter(name = "PSC")
    MWF111 psc(String psc);
    @Parameter(name = "PlatnostKontaktnichUdaju")
    MWF111 platnostKontaktnichUdaju(String platnostKontaktnichUdaju);
    @Parameter(name = "PlatnostPasuDo")
    MWF111 platnostPasuDo(java.util.Date platnostPasuDo);
    @Parameter(name = "PobytCR")
    MWF111 pobytCR(String pobytCR);
    @Parameter(name = "PocetZamestnancu")
    MWF111 pocetZamestnancu(String pocetZamestnancu);
    @Parameter(name = "Posta")
    MWF111 posta(String posta);
    @Parameter(name = "PravniForma")
    MWF111 pravniForma(String pravniForma);
    @Parameter(name = "Prijmeni")
    MWF111 prijmeni(String prijmeni);
    @Parameter(name = "RatingKlienta")
    MWF111 ratingKlienta(String ratingKlienta);
    @Parameter(name = "Rezidence")
    MWF111 rezidence(String rezidence);
    @Parameter(name = "RodneCislo")
    MWF111 rodneCislo(String rodneCislo);
    @Parameter(name = "SerieACisloOP")
    MWF111 serieACisloOP(String serieACisloOP);
    @Parameter(name = "SocialneEkonomickaSkupina")
    MWF111 socialneEkonomickaSkupina(String socialneEkonomickaSkupina);
    @Parameter(name = "SpravniCelek")
    MWF111 spravniCelek(String spravniCelek);
    @Parameter(name = "Telefon")
    MWF111 telefon(String telefon);
    @Parameter(name = "TelefonDalsi")
    MWF111 telefonDalsi(String telefonDalsi);
    @Parameter(name = "TelefonDalsiPredvolba")
    MWF111 telefonDalsiPredvolba(String telefonDalsiPredvolba);
    @Parameter(name = "TelefonMobilni")
    MWF111 telefonMobilni(String telefonMobilni);
    @Parameter(name = "TelefonMobilniPredvolba")
    MWF111 telefonMobilniPredvolba(String telefonMobilniPredvolba);
    @Parameter(name = "TelefonPredvolba")
    MWF111 telefonPredvolba(String telefonPredvolba);
    @Parameter(name = "TitulPred")
    MWF111 titulPred(String titulPred);
    @Parameter(name = "TitulZa")
    MWF111 titulZa(String titulZa);
    @Parameter(name = "TypKlienta")
    MWF111 typKlienta(String typKlienta);
    @Parameter(name = "Ulice")
    MWF111 ulice(String ulice);
    @Parameter(name = "UlozPSCBezKontroly")
    MWF111 ulozPSCBezKontroly(String ulozPSCBezKontroly);
    @Parameter(name = "Urednik")
    MWF111 urednik(String urednik);
    @Parameter(name = "ZECO")
    MWF111 zeco(String zeco);
    @Parameter(name = "Zeme")
    MWF111 zeme(String zeme);
    @Parameter(name = "ZkraceneJmeno")
    MWF111 zkraceneJmeno(String zkraceneJmeno);
}